@@ -2,45 +2,11 @@ import errno
 import inspect
 import io
 import os
-import shutil
 import stat
 import sys
 import tempfile
 
 from ..compatibility import IGNORED_EXCEPTIONS
-from . import TestCase
-
-
-class TempDirMixin(TestCase):
-
-    def setUp(self):
-        self.dir = tempfile.mkdtemp()
-        # force it, since sticky bits spread.
-        os.chmod(self.dir, 0o700)
-
-    def tearDown(self):
-        # change permissions back or rmtree can't kill it
-        if not os.path.exists(self.dir):
-            return
-        for root, dirs, _files in os.walk(self.dir):
-            for directory in dirs:
-                os.chmod(os.path.join(root, directory), 0o700)
-        shutil.rmtree(self.dir)
-
-def tempdir_decorator(func):
-    def f(self, *args, **kwargs):
-        self.dir = tempfile.mkdtemp()
-        try:
-            os.chmod(self.dir, 0o700)
-            return func(self, *args, **kwargs)
-        finally:
-            if os.path.exists(self.dir):
-                for root, dirs, _files in os.walk(self.dir):
-                    for directory in dirs:
-                        os.chmod(os.path.join(root, directory), 0o777)
-                shutil.rmtree(self.dir)
-    f.__name__ = func.__name__
-    return f
 
 
 def mk_named_tempfile(*args, **kwds):
@@ -52,16 +18,16 @@ class PythonNamespaceWalker:
 
     ignore_all_import_failures = False
 
-    valid_inits = frozenset("__init__.%s" % x for x in ("py", "pyc", "pyo", "so"))
+    valid_inits = frozenset(f"__init__.{x}" for x in ("py", "pyc", "pyo", "so"))
 
     # This is for py3.2/PEP3149; dso's now have the interp + major/minor embedded
     # in the name.
     # TODO: update this for pypy's naming
     abi_target = 'cpython-%i%i' % tuple(sys.version_info[:2])
 
-    module_blacklist = frozenset([
+    module_blacklist = frozenset({
         'snakeoil.cli.arghparse', 'snakeoil.pickling',
-    ])
+    })
 
     def _default_module_blacklister(self, target):
         return target in self.module_blacklist or target.startswith('snakeoil.dist')
@@ -80,7 +46,7 @@ class PythonNamespaceWalker:
             mangle = lambda x: x
         else:
             orig_namespace = namespace
-            mangle = lambda x: "%s.%s" % (orig_namespace, x)
+            mangle = lambda x: f"{orig_namespace}.{x}"
         if blacklist_func is None:
             blacklist_func = self._default_module_blacklister
         for mod_name in feed:
@@ -109,21 +75,21 @@ class PythonNamespaceWalker:
         else:
             yield None
 
-        stats = []
+        stats: list[tuple[str, int]] = []
         for x in l:
             try:
                 stats.append((x, os.stat(os.path.join(location, x)).st_mode))
-            except OSError as oe:
-                if oe.errno != errno.ENOENT:
+            except OSError as exc:
+                if exc.errno != errno.ENOENT:
                     raise
                 # file disappeared under our feet... lock file from
                 # trial can cause this.  ignore.
                 import logging
-                logging.debug("file %r disappeared under our feet, ignoring" %
-                              (os.path.join(location, x)))
+                logging.debug("file %r disappeared under our feet, ignoring",
+                              os.path.join(location, x))
 
         seen = set(['__init__'])
-        for (x, st) in stats:
+        for x, st in stats:
             if not (x.startswith(".") or x.endswith("~")) and stat.S_ISREG(st):
                 if (x.endswith(".py") or x.endswith(".pyc")
                         or x.endswith(".pyo") or x.endswith(".so")):
@@ -138,22 +104,22 @@ class PythonNamespaceWalker:
                         seen.add(y)
                         yield y
 
-        for (x, st) in stats:
+        for x, st in stats:
             if stat.S_ISDIR(st):
                 for y in self.recurse(os.path.join(location, x)):
                     if y is None:
                         yield x
                     else:
-                        yield "%s.%s" % (x, y)
+                        yield f"{x}.{y}"
 
     @staticmethod
-    def poor_mans_load(namespace, existance_check=False):
+    def poor_mans_load(namespace, existence_check=False):
         try:
             obj = __import__(namespace)
-            if existance_check:
+            if existence_check:
                 return True
         except:
-            if existance_check:
+            if existence_check:
                 return False
             raise
         for chunk in namespace.split(".")[1:]:
@@ -162,10 +128,9 @@ class PythonNamespaceWalker:
             except IGNORED_EXCEPTIONS:
                 raise
             except AttributeError:
-                raise AssertionError("failed importing target %s" % namespace)
+                raise AssertionError(f"failed importing target {namespace}")
             except Exception as e:
-                raise AssertionError("failed importing target %s; error %s"
-                                     % (namespace, e))
+                raise AssertionError(f"failed importing target {namespace}; error {e}")
         return obj
 
 
@@ -218,7 +183,7 @@ class _classWalker:
 class SubclassWalker(_classWalker):
 
     def walk_derivatives(self, cls, seen=None):
-        if cls == type:
+        if len(inspect.signature(cls.__subclasses__).parameters) != 0:
             return
         if seen is None:
             seen = set()
@@ -238,7 +203,7 @@ class SubclassWalker(_classWalker):
 class KlassWalker(_classWalker):
 
     def walk_derivatives(self, cls, seen=None):
-        if cls == type:
+        if len(inspect.signature(cls.__subclasses__).parameters) != 0:
             return
 
         if seen is None:
